@@ -15,7 +15,7 @@ Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -185,15 +185,18 @@ __END__
  use Indent::Form;
 
  my $indent = Indent::Form->new(%parametes);
- $indent->indent($data_ar, $actual_indent, $non_indent_flag);
+ my $string = $indent->indent($data_ar, $actual_indent, $non_indent_flag);
+ my @string = $indent->indent($data_ar, $actual_indent, $non_indent_flag);
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new(%params)>
+ my $indent = Indent::Form->new(%parametes);
 
- Constructor.
+Constructor.
+
+Returns instance of object.
 
 =over 8
 
@@ -234,16 +237,25 @@ __END__
 
 =back
 
-=item C<indent($data_ar[, $actual_indent, $non_indent_flag])>
+=head2 C<indent>
 
- Indent data. Returns string.
+ my $string = $indent->indent($data_ar, $actual_indent, $non_indent_flag);
+ my @string = $indent->indent($data_ar, $actual_indent, $non_indent_flag);
+
+Indent data. Scalar output is controlled by 'output_separator' parameter.
 
  Arguments:
  $data_ar - Reference to data array ([['key' => 'value'], [..]]);
  $actual_indent - String to actual indent.
  $non_indent_flag - Flag, than says no-indent.
 
-=back
+Returns string or array of strings in array context.
+
+=head1 ENVIRONMENT
+
+Output is controlled by env variable C<NO_COLOR> via L<Term::ANSIColor> Perl
+module. If we set 'ansi' parameter to 1 and env variable C<NO_COLOR> will be 1,
+output will be without ANSI colors. See L<https://no-color.org/>.
 
 =head1 ERRORS
 
@@ -463,12 +475,14 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2011-2020 Michal Josef Špaček
- Artistic License
- BSD 2-Clause License
+© 2011-2021 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
